@@ -9,8 +9,12 @@
 from Filter import addDetails, printError
 from Pkg import getstatusoutput
 import AbstractCheck
+import Config
 
 STANDARD_BIN_DIRS = ['/bin/', '/sbin/', '/usr/bin/', '/usr/sbin/']
+DEFAULT_APPDATA_CHECKER = ('appstream-util', 'validate-relax')
+
+appdata_checker = Config.getOption("AppDataChecker", DEFAULT_APPDATA_CHECKER)
 
 
 class AppDataCheck(AbstractCheck.AbstractFilesCheck):
@@ -25,21 +29,19 @@ class AppDataCheck(AbstractCheck.AbstractFilesCheck):
         root = pkg.dirName()
         f = root + filename
         try:
-            st = getstatusoutput(('appdata-validate', f), True)
+            st = getstatusoutput(appdata_checker + (f,))
         except OSError:
-            # ignore the check if appdata-validate is not install
+            # ignore if the checker is not installed
             return
         if st[0]:
-            for line in st[1].splitlines():
-                if 'problems detected' in line:
-                    printError(pkg, 'invalid-appdata-file', filename)
+            printError(pkg, 'invalid-appdata-file', filename)
 
 
 check = AppDataCheck()
 
 addDetails(
 'invalid-appdata-file',
-'''appdata file is not valid, check with appdata-validate''',
+'''appdata file is not valid, check with %s''' % (" ".join(appdata_checker)),
 )
 
 # Local variables:
