@@ -16,11 +16,7 @@ class ConfigCheck(AbstractCheck.AbstractCheck):
     def __init__(self):
         AbstractCheck.AbstractCheck.__init__(self, "ConfigCheck")
 
-    def check(self, pkg):
-        # Check only binary package
-        if pkg.isSource():
-            return
-
+    def check_binary(self, pkg):
         config_files = pkg.configFiles()
         noreplace_files = pkg.noreplaceFiles()
 
