@@ -22,17 +22,13 @@ vendor = Config.getOption("Vendor")
 distribution = Config.getOption("Distribution")
 compress_ext = Config.getOption("CompressExtension", "bz2")
 
-class DistributionCheck(AbstractCheck.AbstractCheck):
 
+class DistributionCheck(AbstractCheck.AbstractCheck):
 
     def __init__(self):
         AbstractCheck.AbstractCheck.__init__(self, "DistributionCheck")
 
-    def check(self, pkg):
-        # Check only binary package
-        if pkg.isSource():
-            return
-
+    def check_binary(self, pkg):
         if vendor and pkg[rpm.RPMTAG_VENDOR] != vendor:
             printWarning(pkg, "invalid-vendor", pkg[rpm.RPMTAG_VENDOR])
 
@@ -58,7 +54,7 @@ check = DistributionCheck()
 
 addDetails(
 'invalid-vendor',
-'''In the "%s" distribution, vendor should be "%s".''' % (distribution, vendor),
+'In the "%s" distribution, vendor should be "%s".' % (distribution, vendor),
 
 'invalid-distribution',
 'The distribution value should be "' + distribution + '".',
@@ -69,7 +65,7 @@ addDetails(
 automatically when the package is rebuilt, make sure that you have the
 appropriate rpm helper and/or config packages for your target distribution
 installed and try rebuilding again; if it still does not happen automatically,
-you can compress this file in the %%install section of the spec file.''' \
+you can compress this file in the %%install section of the spec file.'''
 % (compress_ext, compress_ext),
 
 'infopage-not-compressed',
@@ -78,7 +74,7 @@ you can compress this file in the %%install section of the spec file.''' \
 automatically when the package is rebuilt, make sure that you have the
 appropriate rpm helper and/or config packages for your target distribution
 installed and try rebuilding again; if it still does not happen automatically,
-you can compress this file in the %%install section of the spec file.''' \
+you can compress this file in the %%install section of the spec file.'''
 % (compress_ext, compress_ext),
 )
 
