@@ -17,6 +17,7 @@
 import rpm
 
 from Filter import addDetails, printWarning
+from Pkg import b2s
 import AbstractCheck
 
 
@@ -34,7 +35,7 @@ class DocFilesCheck(AbstractCheck.AbstractCheck):
             reqs[fname] = [x[0] for x in pkgfile.requires]
 
         core_reqs = {}  # dependencies of non-doc files
-        doc_reqs  = {}  # dependencies of doc files
+        doc_reqs = {}   # dependencies of doc files
 
         for dep in pkg.header.dsFromHeader():
             # skip deps which were found by find-requires
@@ -43,12 +44,14 @@ class DocFilesCheck(AbstractCheck.AbstractCheck):
             core_reqs[dep.N()] = []
 
         # register things which are provided by the package
-        for i in pkg.header[rpm.RPMTAG_PROVIDES] + files.keys():
+        for i in pkg.header[rpm.RPMTAG_PROVIDES]:
+            core_reqs[b2s(i)] = []
+        for i in files:
             core_reqs[i] = []
 
         for i in files:
             if not reqs[i]:
-                continue # skip empty dependencies
+                continue  # skip empty dependencies
             if i in doc_files:
                 target = doc_reqs
             else:
@@ -71,9 +74,9 @@ class DocFilesCheck(AbstractCheck.AbstractCheck):
             if docfile.endswith("/INSTALL"):
                 printWarning(pkg, "install-file-in-docs", docfile)
 
-    def check(self, pkg):
+    def check_binary(self, pkg):
 
-        if pkg.isSource() or not pkg.docFiles():
+        if not pkg.docFiles():
             return
 
         self.__checkRequirements(pkg)
