@@ -17,7 +17,7 @@ import sys
 import rpm
 
 from Filter import addDetails, printError, printWarning
-from Pkg import b2s, catcmd, getstatusoutput, is_utf8, is_utf8_str
+from Pkg import b2s, catcmd, getstatusoutput, is_utf8, is_utf8_bytestr
 import AbstractCheck
 import Config
 
@@ -194,7 +194,7 @@ buildconfig_rpath_regex = re.compile('(?:-rpath|Wl,-R)\\b')
 sofile_regex = re.compile('/lib(64)?/(.+/)?lib[^/]+\.so$')
 devel_regex = re.compile('(.*)-(debug(info)?|devel|headers|source|static)$')
 debuginfo_package_regex = re.compile('-debug(info)?$')
-lib_regex = re.compile('lib(64)?/lib[^/]*\.so\..*')
+lib_regex = re.compile('lib(64)?/lib[^/]*(\.so\..*|-[0-9.]+\.so)')
 ldconfig_regex = re.compile('^[^#]*ldconfig', re.MULTILINE)
 depmod_regex = re.compile('^[^#]*depmod', re.MULTILINE)
 install_info_regex = re.compile('^[^#]*install-info', re.MULTILINE)
@@ -312,7 +312,7 @@ def peek(filename, pkg, length=1024):
     return (chunk, istext)
 
 # See Python sources for a full list of the values here.
-# http://hg.python.org/cpython/file/tip/Lib/importlib/_bootstrap.py
+# http://hg.python.org/cpython/file/tip/Lib/importlib/_bootstrap_external.py
 # http://hg.python.org/cpython/file/2.7/Python/import.c
 _python_magic_values = {
     '2.2': 60717,
@@ -326,6 +326,7 @@ _python_magic_values = {
     '3.2': 3180,
     '3.3': 3230,
     '3.4': 3310,
+    '3.5': 3350,
     }
 
 
@@ -394,17 +395,17 @@ class FilesCheck(AbstractCheck.AbstractCheck):
 
     def check(self, pkg):
 
-        files = pkg.files()
-
         if use_utf8:
-            for filename in files:
-                if not is_utf8_str(filename):
-                    printError(pkg, 'filename-not-utf8', filename)
+            for filename in pkg.header[rpm.RPMTAG_FILENAMES] or ():
+                if not is_utf8_bytestr(filename):
+                    printError(pkg, 'filename-not-utf8', b2s(filename))
 
         # Rest of the checks are for binary packages only
         if pkg.isSource():
             return
 
+        files = pkg.files()
+
         # Check if the package is a development package
         devel_pkg = devel_regex.search(pkg.name)
 
@@ -421,7 +422,7 @@ class FilesCheck(AbstractCheck.AbstractCheck):
         python_dep_error = False
         lib_file = False
         non_lib_file = None
-        log_file = None
+        log_files = []
         logrotate_file = False
         debuginfo_srcs = False
         debuginfo_debugs = False
@@ -512,13 +513,13 @@ class FilesCheck(AbstractCheck.AbstractCheck):
             mode_is_exec = mode & int("111", 8)
 
             if log_regex.search(f):
-                log_file = f
+                log_files.append(f)
 
             # Hardlink check
-            hardlink = hardlinks.get((rdev, inode))
-            if hardlink and os.path.dirname(hardlink) != os.path.dirname(f):
-                printWarning(pkg, 'cross-directory-hard-link', f, hardlink)
-            hardlinks[(rdev, inode)] = f
+            for hardlink in hardlinks.get((rdev, inode), ()):
+                if os.path.dirname(hardlink) != os.path.dirname(f):
+                    printWarning(pkg, 'cross-directory-hard-link', f, hardlink)
+            hardlinks.setdefault((rdev, inode), []).append(f)
 
             # normal file check
             if stat.S_ISREG(mode):
@@ -526,24 +527,24 @@ class FilesCheck(AbstractCheck.AbstractCheck):
                 # set[ug]id bit check
                 if stat.S_ISGID & mode or stat.S_ISUID & mode:
                     if stat.S_ISUID & mode:
-                        printError(pkg, 'setuid-binary', f, user, oct(perm))
+                        printError(pkg, 'setuid-binary', f, user, "%o" % perm)
                     if stat.S_ISGID & mode:
                         if not (group == 'games' and
                                 (games_path_regex.search(f) or
                                  games_group_regex.search(
                                     pkg[rpm.RPMTAG_GROUP]))):
                             printError(pkg, 'setgid-binary', f, group,
-                                       oct(perm))
+                                       "%o" % perm)
                     if mode & int("777", 8) != int("755", 8):
                         printError(pkg, 'non-standard-executable-perm', f,
-                                   oct(perm))
+                                   "%o" % perm)
 
                 # Prefetch scriptlets, strip quotes from them (#169)
-                postin = b2s(pkg[rpm.RPMTAG_POSTIN]) or \
+                postin = pkg[rpm.RPMTAG_POSTIN] or \
                          pkg.scriptprog(rpm.RPMTAG_POSTINPROG)
                 if postin:
                     postin = quotes_regex.sub('', postin)
-                postun = b2s(pkg[rpm.RPMTAG_POSTUN]) or \
+                postun = pkg[rpm.RPMTAG_POSTUN] or \
                          pkg.scriptprog(rpm.RPMTAG_POSTUNPROG)
                 if postun:
                     postun = quotes_regex.sub('', postun)
@@ -582,6 +583,8 @@ class FilesCheck(AbstractCheck.AbstractCheck):
 
                 # check ldconfig call in %post and %postun
                 if lib_regex.search(f):
+                    if devel_pkg:
+                        printError(pkg, 'non-devel-file-in-devel-package', f)
                     if not postin:
                         printError(pkg, 'library-without-ldconfig-postin', f)
                     else:
@@ -624,7 +627,7 @@ class FilesCheck(AbstractCheck.AbstractCheck):
                     elif not install_info_regex.search(postin):
                         printError(pkg, 'postin-without-install-info', f)
 
-                    preun = b2s(pkg[rpm.RPMTAG_PREUN]) or \
+                    preun = pkg[rpm.RPMTAG_PREUN] or \
                             pkg.scriptprog(rpm.RPMTAG_PREUNPROG)
                     if not postun and not preun:
                         printError(pkg,
@@ -638,7 +641,7 @@ class FilesCheck(AbstractCheck.AbstractCheck):
                 if perl_temp_file_regex.search(f):
                     printWarning(pkg, 'perl-temp-file', f)
 
-                is_buildconfig = buildconfigfile_regex.search(f) and True
+                is_buildconfig = istext and buildconfigfile_regex.search(f)
 
                 # check rpaths in buildconfig files
                 if is_buildconfig:
@@ -650,7 +653,7 @@ class FilesCheck(AbstractCheck.AbstractCheck):
                 if res:
                     if not mode_is_exec:
                         printWarning(pkg, 'non-executable-in-bin', f,
-                                     oct(perm))
+                                     "%o" % perm)
                     else:
                         exe = res.group(1)
                         if "/" not in exe:
@@ -668,13 +671,13 @@ class FilesCheck(AbstractCheck.AbstractCheck):
                             ok_nonreadable = True
                             break
                     if not ok_nonreadable:
-                        printError(pkg, 'non-readable', f, oct(perm))
+                        printError(pkg, 'non-readable', f, "%o" % perm)
                 if size == 0 and not normal_zero_length_regex.search(f) and \
                         f not in ghost_files:
                     printError(pkg, 'zero-length', f)
 
                 if mode & stat.S_IWOTH:
-                    printError(pkg, 'world-writable', f, oct(perm))
+                    printError(pkg, 'world-writable', f, "%o" % perm)
 
                 if not perl_dep_error:
                     res = perl_regex.search(f)
@@ -748,7 +751,7 @@ class FilesCheck(AbstractCheck.AbstractCheck):
                 # normal executable check
                 if mode & stat.S_IXUSR and perm != int("755", 8):
                     printError(pkg, 'non-standard-executable-perm',
-                               f, oct(perm))
+                               f, "%o" % perm)
                 if mode_is_exec:
                     if f in config_files:
                         printError(pkg, 'executable-marked-as-config-file', f)
@@ -818,7 +821,7 @@ class FilesCheck(AbstractCheck.AbstractCheck):
                                        interpreter)
                         if mode_is_exec:
                             printError(pkg, 'executable-sourced-script',
-                                       f, oct(perm))
+                                       f, "%o" % perm)
                     # ...but executed ones should
                     elif interpreter or mode_is_exec or script_regex.search(f):
                         if interpreter:
@@ -832,7 +835,7 @@ class FilesCheck(AbstractCheck.AbstractCheck):
 
                         if not mode_is_exec and not is_doc:
                             printError(pkg, 'non-executable-script', f,
-                                       oct(perm), interpreter)
+                                       "%o" % perm, interpreter)
                         if b'\r' in chunk:
                             printError(
                                 pkg, 'wrong-script-end-of-line-encoding', f)
@@ -859,9 +862,9 @@ class FilesCheck(AbstractCheck.AbstractCheck):
             # normal dir check
             elif stat.S_ISDIR(mode):
                 if mode & int("1002", 8) == 2:  # world writable w/o sticky bit
-                    printError(pkg, 'world-writable', f, oct(perm))
+                    printError(pkg, 'world-writable', f, "%o" % perm)
                 if perm != int("755", 8):
-                    printError(pkg, 'non-standard-dir-perm', f, oct(perm))
+                    printError(pkg, 'non-standard-dir-perm', f, "%o" % perm)
                 if pkg.name not in filesys_packages and f in STANDARD_DIRS:
                     printError(pkg, 'standard-dir-owned-by-package', f)
                 if hidden_file_regex.search(f):
@@ -975,8 +978,8 @@ class FilesCheck(AbstractCheck.AbstractCheck):
                 if stat.S_IWGRP & mode or stat.S_IWOTH & mode:
                     printError(pkg, 'non-owner-writeable-only-crontab-file', f)
 
-        if log_file and not logrotate_file:
-            printWarning(pkg, 'log-files-without-logrotate', log_file)
+        if len(log_files) and not logrotate_file:
+            printWarning(pkg, 'log-files-without-logrotate', sorted(log_files))
 
         if lib_package and lib_file and non_lib_file:
             printError(pkg, 'outside-libdir-files', non_lib_file)
@@ -1106,6 +1109,9 @@ that the file is an executable or that it has executable permissions.''',
 package. If you want to include source code in your package, be sure to
 create a development package.''',
 
+'non-devel-file-in-devel-package',
+'''A non-development file is located in a devel package.''',
+
 'non-standard-dir-perm',
 '''A standard directory should have permission set to 0755. If you get this
 message, it means that you have wrong directory permissions in some dirs
@@ -1362,7 +1368,6 @@ for i in disallowed_dirs:
 for packages to install files in this directory.''' % i)
 
 
-
 # FilesCheck.py ends here
 
 # Local variables:
