@@ -26,7 +26,7 @@ INCORRECT_LOCALES = {
     'gr_GR': 'el_GR',
     'cz': 'cs',
     'cz_CZ': 'cs_CZ',
-    'lug': 'lg', # 'lug' is valid, but we standardize on 2 letter codes
+    'lug': 'lg',  # 'lug' is valid, but we standardize on 2 letter codes
     'en_UK': 'en_GB'}
 
 package_regex = re.compile('-(' + '|'.join(LANGUAGES) + ')$')
@@ -40,11 +40,13 @@ man_regex = re.compile('/usr(?:/share)?/man/([^/]+)/man[0-9n][^/]*/[^/]+$')
 # note: ISO-8859-9E is non standard, ISO-8859-{6,8} are of limited use
 # as locales (since all modern handling of bidi is based on utf-8 anyway),
 # so they should be removed once UTF-8 is deployed)
-EXCEPTION_DIRS = ('C', 'POSIX', 'CP1251', 'CP1255', 'CP1256',
-'ISO-8859-1', 'ISO-8859-2', 'ISO-8859-3', 'ISO-8859-4', 'ISO-8859-5',
-'ISO-8859-6', 'ISO-8859-7', 'ISO-8859-8', 'ISO-8859-9', 'ISO-8859-9E',
-'ISO-8859-10', 'ISO-8859-13', 'ISO-8859-14', 'ISO-8859-15',
-'KOI8-R', 'KOI8-U', 'UTF-8', 'default')
+EXCEPTION_DIRS = (
+    'C', 'POSIX', 'CP1251', 'CP1255', 'CP1256',
+    'ISO-8859-1', 'ISO-8859-2', 'ISO-8859-3', 'ISO-8859-4', 'ISO-8859-5',
+    'ISO-8859-6', 'ISO-8859-7', 'ISO-8859-8', 'ISO-8859-9', 'ISO-8859-9E',
+    'ISO-8859-10', 'ISO-8859-13', 'ISO-8859-14', 'ISO-8859-15',
+    'KOI8-R', 'KOI8-U', 'UTF-8', 'default')
+
 
 def is_valid_lang(lang):
     # TODO: @Foo and charset handling
@@ -69,17 +71,14 @@ def is_valid_lang(lang):
 
     return True
 
+
 class I18NCheck(AbstractCheck.AbstractCheck):
 
     def __init__(self):
         AbstractCheck.AbstractCheck.__init__(self, 'I18NCheck')
 
-    def check(self, pkg):
-
-        if pkg.isSource():
-            return
-
-        files = pkg.files().keys()
+    def check_binary(self, pkg):
+        files = list(pkg.files().keys())
         files.sort()
         locales = []                      # list of locales for this packages
         webapp = False
@@ -154,6 +153,7 @@ class I18NCheck(AbstractCheck.AbstractCheck):
                 if locales not in (x[0] for x in pkg.requires()):
                     printError(pkg, 'no-dependency-on', locales)
 
+
 def is_prefix(p, s):
     return len(p) <= len(s) and p == s[:len(p)]
 
