@@ -9,17 +9,20 @@
 from Filter import addDetails, printError, printWarning
 from Pkg import getstatusoutput, is_utf8
 import AbstractCheck
-from ConfigParser import RawConfigParser
+try:
+    from ConfigParser import RawConfigParser
+except:
+    from configparser import RawConfigParser
 import os
 
-STANDARD_BIN_DIRS = ['/bin/','/sbin/','/usr/bin/','/usr/sbin/']
+STANDARD_BIN_DIRS = ['/bin/', '/sbin/', '/usr/bin/', '/usr/sbin/']
+
 
 class MenuXDGCheck(AbstractCheck.AbstractFilesCheck):
     def __init__(self):
         # desktop file need to be in $XDG_DATA_DIRS
         # $ echo $XDG_DATA_DIRS/applications
         # /var/lib/menu-xdg:/usr/share
-        self.cfp = RawConfigParser()
         AbstractCheck.AbstractFilesCheck.__init__(
             self, "MenuXDGCheck", "/usr/share/applications/.*\.desktop$")
 
@@ -39,16 +42,25 @@ class MenuXDGCheck(AbstractCheck.AbstractFilesCheck):
         if not is_utf8(f):
             printError(pkg, 'non-utf8-desktopfile', filename)
 
-        self.cfp.read(f)
-        binary = self.cfp.get('Desktop Entry','Exec').split(' ',1)[0]
-        found = False
-        for i in STANDARD_BIN_DIRS:
-            if os.path.exists(root + i + binary):
-                # no need to check if the binary is +x, rpmlint does it
-                # in another place
-                found = True
-        if not found and binary:
-            printWarning(pkg, 'desktopfile-without-binary', filename, binary)
+        cfp = RawConfigParser()
+        cfp.read(f)
+        binary = None
+        if cfp.has_option('Desktop Entry', 'Exec'):
+            binary = cfp.get('Desktop Entry', 'Exec').split(' ', 1)[0]
+        if binary:
+            found = False
+            if binary.startswith('/'):
+                found = os.path.exists(root + binary)
+            else:
+                for i in STANDARD_BIN_DIRS:
+                    if os.path.exists(root + i + binary):
+                        # no need to check if the binary is +x, rpmlint does it
+                        # in another place
+                        found = True
+                        break
+            if not found:
+                printWarning(pkg, 'desktopfile-without-binary', filename,
+                             binary)
 
 check = MenuXDGCheck()
 
