@@ -13,7 +13,6 @@ import re
 import subprocess
 import sys
 import tempfile
-import unicodedata
 try:
     from urlparse import urljoin
 except:
@@ -37,6 +36,7 @@ if sys.version_info[0] > 2:
     # Blows up with Python < 3 without the exec() hack
     exec('def warn(s): print (s, file=sys.stderr)')
     long = int
+    unicode = str
 
     def b2s(b):
         if b is None:
@@ -62,6 +62,17 @@ PREREQ_FLAG = (rpm.RPMSENSE_PREREQ or 64) | \
               rpm.RPMSENSE_SCRIPT_PREUN | \
               rpm.RPMSENSE_SCRIPT_POSTUN
 
+SCRIPT_TAGS = [
+    (rpm.RPMTAG_PREIN,          rpm.RPMTAG_PREINPROG,         '%pre'),
+    (rpm.RPMTAG_POSTIN,         rpm.RPMTAG_POSTINPROG,        '%post'),
+    (rpm.RPMTAG_PREUN,          rpm.RPMTAG_PREUNPROG,         '%preun'),
+    (rpm.RPMTAG_POSTUN,         rpm.RPMTAG_POSTUNPROG,        '%postun'),
+    (rpm.RPMTAG_TRIGGERSCRIPTS, rpm.RPMTAG_TRIGGERSCRIPTPROG, '%trigger'),
+    (rpm.RPMTAG_PRETRANS,       rpm.RPMTAG_PRETRANSPROG,      '%pretrans'),
+    (rpm.RPMTAG_POSTTRANS,      rpm.RPMTAG_POSTTRANSPROG,     '%posttrans'),
+    (rpm.RPMTAG_VERIFYSCRIPT,   rpm.RPMTAG_VERIFYSCRIPTPROG,  '%verifyscript'),
+    ]
+
 var_regex = re.compile('^(.*)\${?(\w+)}?(.*)$')
 
 
@@ -91,7 +102,7 @@ def substitute_shell_vars(val, script):
         return val
 
 
-def getstatusoutput(cmd, stdoutonly=False, shell=False):
+def getstatusoutput(cmd, stdoutonly=False, shell=False, raw=False):
     '''A version of commands.getstatusoutput() which can take cmd as a
        sequence, thus making it potentially more secure.'''
     if stdoutonly:
@@ -102,12 +113,15 @@ def getstatusoutput(cmd, stdoutonly=False, shell=False):
                                 stdout=subprocess.PIPE,
                                 stderr=subprocess.STDOUT, close_fds=True)
     proc.stdin.close()
-    text = b2s(proc.stdout.read())
+    with proc.stdout:
+        text = proc.stdout.read()
     sts = proc.wait()
+    if not raw:
+        text = b2s(text)
+        if text.endswith('\n'):
+            text = text[:-1]
     if sts is None:
         sts = 0
-    if text.endswith('\n'):
-        text = text[:-1]
     return sts, text
 
 bz2_regex = re.compile('\.t?bz2?$')
@@ -125,59 +139,38 @@ def catcmd(fname):
 
 
 def is_utf8(fname):
-    (sts, text) = getstatusoutput(catcmd(fname).split() + [fname])
-    return not sts and is_utf8_str(text)
-
-REPLACEMENT_CHAR = unicodedata.lookup('REPLACEMENT CHARACTER')
+    (sts, output) = getstatusoutput(catcmd(fname).split() + [fname], raw=True)
+    return not sts and is_utf8_bytestr(output)
 
 
-def is_utf8_str(s):
-    if hasattr(s, 'decode'):
-        # byte string
-        try:
-            s.decode('UTF-8')
-        except:
-            return False
-        return True
-    # unicode string
-    return REPLACEMENT_CHAR not in s
+def is_utf8_bytestr(s):
+    try:
+        s.decode('UTF-8')
+    except:
+        return False
+    return True
 
 
-# TODO: PY3
-def to_utf8(string):
+def to_unicode(string):
     if string is None:
-        return ''
+        return unicode('')
     elif isinstance(string, unicode):
         return string
-    try:
-        x = unicode(string, 'ascii')
-        return string
-    except UnicodeError:
-        encodings = ['utf-8', 'iso-8859-1', 'iso-8859-15', 'iso-8859-2']
-        for enc in encodings:
-            try:
-                x = unicode(string, enc)
-            except UnicodeError:
-                pass
-            else:
-                if x.encode(enc) == string:
-                    return x.encode('utf-8')
-    newstring = ''
-    for char in string:
-        if ord(char) > 127:
-            newstring = newstring + '?'
+    for enc in ('utf-8', 'iso-8859-1', 'iso-8859-15', 'iso-8859-2'):
+        try:
+            x = unicode(string, enc)
+        except UnicodeError:
+            pass
         else:
-            newstring = newstring + char
-    return newstring
+            if x.encode(enc) == string:
+                return x
+    return unicode(string, "ascii", errors="replace")
 
 
 def readlines(path):
-    fobj = open(path, 'rb')
-    try:
+    with open(path, 'rb') as fobj:
         for line in fobj:
             yield b2s(line)
-    finally:
-        fobj.close()
 
 
 def mktemp():
@@ -204,20 +197,13 @@ def get_default_valid_rpmgroups(filename=None):
     the rpm package (if installed) if no filename is given"""
     groups = []
     if not filename:
-        try:
-            p = InstalledPkg('rpm')
-        except:
-            pass
-        else:
+        with InstalledPkg("rpm") as p:
             groupsfiles = [x for x in p.files() if x.endswith('/GROUPS')]
             if groupsfiles:
                 filename = groupsfiles[0]
     if filename and os.path.exists(filename):
-        fobj = open(filename)
-        try:
+        with open(filename) as fobj:
             groups = fobj.read().strip().splitlines()
-        finally:
-            fobj.close()
         if 'Development/Debug' not in groups:
             groups.append('Development/Debug')
         if 'Unspecified' not in groups:  # auto-added by rpm >= 4.6.0
@@ -450,7 +436,19 @@ def parse_deps(line):
 
 # classes representing package
 
-class Pkg:
+class AbstractPkg:
+
+    def cleanup(self):
+        pass
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.cleanup()
+
+
+class Pkg(AbstractPkg):
 
     _magic_from_compressed_re = re.compile('\([^)]+\s+compressed\s+data\\b')
 
@@ -483,7 +481,7 @@ class Pkg:
                 os.close(fd)
             self.is_source = not self.header[rpm.RPMTAG_SOURCERPM]
 
-        self.name = b2s(self.header[rpm.RPMTAG_NAME])
+        self.name = self[rpm.RPMTAG_NAME]
         if self.isNoSource():
             self.arch = 'nosrc'
         elif self.isSource():
@@ -509,9 +507,14 @@ class Pkg:
         if val == []:
             return None
         else:
-            if key in (rpm.RPMTAG_VERSION, rpm.RPMTAG_RELEASE, rpm.RPMTAG_ARCH,
-                       rpm.RPMTAG_GROUP, rpm.RPMTAG_BUILDHOST,
-                       rpm.RPMTAG_LICENSE):
+            # Note that text tags we want to try decoding for real in TagsCheck
+            # such as summary, description and changelog are not here.
+            if key in (rpm.RPMTAG_NAME, rpm.RPMTAG_VERSION, rpm.RPMTAG_RELEASE,
+                       rpm.RPMTAG_ARCH, rpm.RPMTAG_GROUP, rpm.RPMTAG_BUILDHOST,
+                       rpm.RPMTAG_LICENSE, rpm.RPMTAG_HEADERI18NTABLE,
+                       rpm.RPMTAG_PACKAGER, rpm.RPMTAG_SOURCERPM) \
+            or key in (x[0] for x in SCRIPT_TAGS) \
+            or key in (x[1] for x in SCRIPT_TAGS):
                 val = b2s(val)
             return val
 
@@ -573,7 +576,7 @@ class Pkg:
         # LANGUAGE trumps other env vars per GNU gettext docs, see also #166
         orig = os.environ.get('LANGUAGE')
         os.environ['LANGUAGE'] = lang
-        ret = b2s(self[tag])
+        ret = self[tag]
         if orig is not None:
             os.environ['LANGUAGE'] = orig
         return ret
@@ -666,8 +669,8 @@ class Pkg:
                     self.dirName() or '/', pkgfile.name.lstrip('/')))
                 pkgfile.flags = flags[idx]
                 pkgfile.mode = modes[idx]
-                pkgfile.user = users[idx]
-                pkgfile.group = groups[idx]
+                pkgfile.user = b2s(users[idx])
+                pkgfile.group = b2s(groups[idx])
                 pkgfile.linkto = links[idx] and safe_normpath(links[idx])
                 pkgfile.size = sizes[idx]
                 pkgfile.md5 = md5s[idx]
@@ -676,7 +679,7 @@ class Pkg:
                 pkgfile.inode = inodes[idx]
                 pkgfile.requires = parse_deps(requires[idx])
                 pkgfile.provides = parse_deps(provides[idx])
-                pkgfile.lang = langs[idx]
+                pkgfile.lang = b2s(langs[idx])
                 pkgfile.magic = magics[idx]
                 if not pkgfile.magic and _magic:
                     pkgfile.magic = _magic.file(pkgfile.path)
@@ -750,6 +753,30 @@ class Pkg:
         self._gatherDepInfo()
         return self._provides
 
+    def recommends(self):
+        """Get package Recommends as list of
+           (name, flags, (epoch, version, release)) tuples."""
+        self._gatherDepInfo()
+        return self._recommends
+
+    def suggests(self):
+        """Get package Suggests as list of
+           (name, flags, (epoch, version, release)) tuples."""
+        self._gatherDepInfo()
+        return self._suggests
+
+    def enhances(self):
+        """Get package Enhances as list of
+           (name, flags, (epoch, version, release)) tuples."""
+        self._gatherDepInfo()
+        return self._enhances
+
+    def supplements(self):
+        """Get package Supplements as list of
+           (name, flags, (epoch, version, release)) tuples."""
+        self._gatherDepInfo()
+        return self._supplements
+
     # internal function to gather dependency info used by the above ones
     def _gather_aux(self, header, list, nametag, flagstag, versiontag,
                     prereq=None):
@@ -773,6 +800,10 @@ class Pkg:
             self._provides = []
             self._conflicts = []
             self._obsoletes = []
+            self._recommends = []
+            self._suggests = []
+            self._enhances = []
+            self._supplements = []
 
             self._gather_aux(self.header, self._requires,
                              rpm.RPMTAG_REQUIRENAME,
@@ -791,6 +822,26 @@ class Pkg:
                              rpm.RPMTAG_OBSOLETENAME,
                              rpm.RPMTAG_OBSOLETEFLAGS,
                              rpm.RPMTAG_OBSOLETEVERSION)
+            if hasattr(rpm, "RPMTAG_RECOMMENDNAME"):  # rpm >= 4.12
+                self._gather_aux(self.header, self._recommends,
+                                 rpm.RPMTAG_RECOMMENDNAME,
+                                 rpm.RPMTAG_RECOMMENDFLAGS,
+                                 rpm.RPMTAG_RECOMMENDVERSION)
+            if hasattr(rpm, "RPMTAG_SUGGESTNAME"):  # rpm >= 4.12
+                self._gather_aux(self.header, self._suggests,
+                                 rpm.RPMTAG_SUGGESTNAME,
+                                 rpm.RPMTAG_SUGGESTFLAGS,
+                                 rpm.RPMTAG_SUGGESTVERSION)
+            if hasattr(rpm, "RPMTAG_ENHANCENAME"):  # rpm >= 4.12
+                self._gather_aux(self.header, self._enhances,
+                                 rpm.RPMTAG_ENHANCENAME,
+                                 rpm.RPMTAG_ENHANCEFLAGS,
+                                 rpm.RPMTAG_ENHANCEVERSION)
+            if hasattr(rpm, "RPMTAG_SUPPLEMENTNAME"):  # rpm >= 4.12
+                self._gather_aux(self.header, self._supplements,
+                                 rpm.RPMTAG_SUPPLEMENTNAME,
+                                 rpm.RPMTAG_SUPPLEMENTFLAGS,
+                                 rpm.RPMTAG_SUPPLEMENTVERSION)
 
     def scriptprog(self, which):
         """Get the specified script interpreter as a string.
@@ -798,11 +849,11 @@ class Pkg:
            interpreter arguments, if any."""
         prog = self[which]
         if prog is None:
-            prog = b''
+            prog = ""
         elif isinstance(prog, (list, tuple)):
             # http://rpm.org/ticket/847#comment:2
-            prog = b' '.join(prog)
-        return b2s(prog)
+            prog = "".join(prog)
+        return prog
 
 
 def getInstalledPkgs(name):
@@ -831,7 +882,7 @@ class InstalledPkg(Pkg):
             if not mi:
                 raise KeyError(name)
             try:
-                hdr = mi.next()
+                hdr = next(mi)
             except StopIteration:
                 raise KeyError(name)
 
@@ -851,15 +902,12 @@ class InstalledPkg(Pkg):
 
 
 # Class to provide an API to a "fake" package, eg. for specfile-only checks
-class FakePkg:
+class FakePkg(AbstractPkg):
     def __init__(self, name):
         self.name = name
         self.arch = None
         self.current_linenum = None
 
-    def cleanup(self):
-        pass
-
 
 # Class for files in packages
 class PkgFile(object):
@@ -895,13 +943,12 @@ class PkgFile(object):
 
 if __name__ == '__main__':
     for p in sys.argv[1:]:
-        pkg = Pkg(sys.argv[1], tempfile.gettempdir())
-        print ('Requires: %s' % pkg.requires())
-        print ('Prereq: %s' % pkg.prereq())
-        print ('Conflicts: %s' % pkg.conflicts())
-        print ('Provides: %s' % pkg.provides())
-        print ('Obsoletes: %s' % pkg.obsoletes())
-        pkg.cleanup()
+        with Pkg(p, tempfile.gettempdir()) as pkg:
+            print('Requires: %s' % pkg.requires())
+            print('Prereq: %s' % pkg.prereq())
+            print('Conflicts: %s' % pkg.conflicts())
+            print('Provides: %s' % pkg.provides())
+            print('Obsoletes: %s' % pkg.obsoletes())
 
 # Pkg.py ends here
 
