@@ -8,6 +8,7 @@
 #############################################################################
 
 import re
+import sys
 import unicodedata
 try:
     from urlparse import urlparse
@@ -96,6 +97,7 @@ conflicts_regex = re.compile('^(?:Build)?Conflicts:\s*(.*)', re.IGNORECASE)
 
 compop_regex = re.compile('[<>=]')
 
+setup_regex = re.compile(r'%setup\b')  # intentionally no whitespace before!
 setup_q_regex = re.compile(' -[A-Za-z]*q')
 setup_t_regex = re.compile(' -[A-Za-z]*T')
 setup_ab_regex = re.compile(' -[A-Za-z]*[ab]')
@@ -154,11 +156,9 @@ class SpecCheck(AbstractCheck.AbstractCheck):
             # check content of spec file
             self.check_spec(pkg, self._spec_file)
 
-    def check_spec(self, pkg, spec_file, spec_lines=[]):
+    def check_spec(self, pkg, spec_file):
         self._spec_file = spec_file
         spec_only = isinstance(pkg, Pkg.FakePkg)
-        if not spec_lines:
-            spec_lines = Pkg.readlines(spec_file)
         patches = {}
         applied_patches = []
         applied_patches_ifarch = []
@@ -198,12 +198,13 @@ class SpecCheck(AbstractCheck.AbstractCheck):
         nbsp = chr(0xA0)
         if is_utf8:
             nbsp = UNICODE_NBSP
+        do_unicode = is_utf8 and sys.version_info[0] <= 2
 
-        for line in spec_lines:
+        for line in Pkg.readlines(spec_file):
 
             pkg.current_linenum += 1
 
-            if is_utf8:
+            if do_unicode:
                 line = unicode(line, "utf-8", "replace")
 
             char = line.find(nbsp)
@@ -259,7 +260,7 @@ class SpecCheck(AbstractCheck.AbstractCheck):
             if if_regex.search(line):
                 if_depth = if_depth + 1
 
-            if line.startswith('%setup'):
+            if setup_regex.match(line):
                 if not setup_q_regex.search(line):
                     # Don't warn if there's a -T without -a or -b
                     if setup_t_regex.search(line):
