@@ -2,13 +2,17 @@
 
 import re
 import unittest
+
 import Testing
 import SpecCheck
 
+
 class TestSpecCheck(unittest.TestCase):
+
     def setUp(self):
-        self.pkg = Testing.getTestedSpecPackage('SpecCheck')
+        self.pkg = Testing.getTestedSpecPackage('spec/SpecCheck')
         Testing.startTest()
+
     def testcheck(self):
         SpecCheck.check.check_spec(self.pkg, self.pkg.name)
         out = "\n".join(Testing.getOutput())
@@ -25,6 +29,7 @@ class TestSpecCheck(unittest.TestCase):
                         in out)
         self.assertTrue("unversioned-explicit-obsoletes versioned-obsoletes"
                         not in out)
+        self.assertTrue("setup-not-quiet" in out)
 
 if __name__ == '__main__':
     unittest.main()
